/* ---------------------------------------------------------------------------
** datum.h      Headerdatei fr Funktionen zur Datums- und Zeitbehandlung
** ---------------------------------------------------------------------------
*/

/* Mehrfacheinbindungen vermeiden :
*/
#ifndef __DATUM__
#define __DATUM__

/* Symbole :
** ---------
*/

/* Falls CURSES eingebunden wurde, sind TRUE und FALSE bereits definiert :
** ( Vermeidet Warnungen des Compilers ! )
*/
#ifndef TRUE
#define TRUE       (1)
#endif
#ifndef FALSE
#define FALSE      (0)
#endif

/* Fr die Datumsfunktionen :
*/
#define FEHLER     90909090
/* Formate : */
#define DE_KURZ    1
#define DE_LANG    2
#define AM_KURZ    3
#define AM_LANG    4
#define DB_KURZ    5
#define DB_LANG    6
#define DE_AKTJAHR 7
#define AM_AKTJAHR 8
/* Wochentage : */
#define MONTAG     1
#define DIENSTAG   2
#define MITTWOCH   3
#define DONNERSTAG 4
#define FREITAG    5
#define SAMSTAG    6
#define SONNTAG    7

/* Fr die Zeitfunktionen :
*/
/* Formate : */
#define TI_DEF_FORM 2
#define TI_HM_D     1
#define TI_HMS_D    2
#define TI_HM_P     3
#define TI_HMS_P    4
#define TI_HM_DB    5
#define TI_HMS_DB   6
#define TI_MIN_SEC  100
/* Diverse Werte : */
#define TI_MAX_SEC  86399L
#define TI_MAX_MIN  1439L
#define TI_MAX_HOUR 23L
#define TI_MAX_VAL  "23:59:59"
#define TI_DEF_VAL  "00:00:00"

/* Deklarationen :
** ---------------
*/
/* Datumsfunktionen :
*/
extern char *calcdate(char *datum, long abstand, char *erg);
extern int   checkdate(char *datum);
extern char *cnvtdate(char *datum, int dest_format, char *erg);
extern long  diffdate(char *datum1, char *datum2);
extern char *himmelf_s(int jahr);
extern char *mk_datestr(int tag, int monat, int jahr, int format);
extern char *ostern_s(int jahr);
extern char *pfingsten_s(int jahr);
extern char *readdate(int format, char *dest);
extern int   schalt_jahr(int jahr);
extern char *today(int format);
extern char *tomorrow(int format);
extern int   weekday(int tag,int monat,int jahr);
extern char *yesterday(int format);

/* Zeitfunktionen :
*/
extern char *calctime(char *zeit, long abstand, char *erg);
extern int   checktime(char *zeit);
extern char *cnvttime(char *zeit, int dest_format, char *erg);
extern long  diffdtime(char *zeit1, char *zeit2);
extern char *mk_timestr(unsigned long min_sec, int toggle, int format);
extern char *now(int format);
extern char *readtime(int format, char *dest);

/* CURSES-SEKTION: Funktionen und -Makros (nur einbinden, wenn bentigt):
** ----------------------------------------------------------------------
*/
#ifdef __CURSES__

/* Eigene Funktionen :
*/
extern char *wreaddatew(WINDOW *win,int format, char *dest);
extern char *readdatew(int format, char *dest);
extern char *wreadtimew(WINDOW *win,int format, char *dest);
extern char *readtimew(int format, char *dest);

/* Zugehrige Makros :
*/
#define mvwreaddatew(win,row,col,format,dest) (wmove(win,row,col),\
                                               wreaddatew(win,format,dest))
#define mvreaddatew(win,row,col,format,dest)  (move(row,col),\
                                               readdatew(format,dest))
#define mvwreadtimew(win,row,col,format,dest) (wmove(win,row,col),\
                                               wreadtimew(win,format,dest))
#define mvreadtimew(win,row,col,format,dest)  (move(row,col),\
                                               readtimew(format,dest))
#endif /* __CURSES__ */

/* ------------------------> CURSES-SEKTION <------------------------------ */

#endif /* __DATUM__ */

